# Disaster Dollar Database (DDD) Dataset

## Overview

Disaster Dollar Database is a program led by Sarah Labowitz through the Carnegie Endowment for International Peace. This dataset tracks federal disaster declarations and associated funding allocations across multiple programs: FEMA Individuals and Households Program (IHP), FEMA Public Assistance (PA), and HUD’s Community Development Block Grant-Disaster Recovery (CDBG-DR) program. FEMA data was accessed through OpenFEMA. HUD data was collected through the Federal Register.

## Data Structure

The dataset is organized by incident, with each row representing a unique event.

### Key Columns

#### Event Information

- `year`: Year of the disaster event  
- `event`: Name/description of the disaster event; formatted based on FEMA’s typical event name on its individual incident websites  
- `incident_number`: Unique FEMA identifier for the disaster incident  
- `incident_start`: Start date of the incident (YYYY-MM-DD) as determined by FEMA  
- `incident_end`: End date of the incident (YYYY-MM-DD) as determined by FEMA  
- `declaration_date`: Date of presidential disaster declaration (YYYY-MM-DD)   
- `declaration_url`: Link to the official FEMA incident website. Note that FEMA is not consistent in posting websites in English or Spanish; some pages may be in Spanish.  
- `state`: State abbreviation where the incident occurred. Note that the same event may impact multiple jurisdictions (e.g. Hurricane Isabel in North Carolina, Virginia, Maryland, District of Columbia, Delaware, and West Virginia); FEMA assigns individual incident numbers to each jurisdiction.   
- `incident_type`: Type of event (e.g., hurricane, flood) as determined by FEMA

#### Assistance Programs

- `valid_ihp_applications`: Number of valid FEMA Individual and Household Program applications  
- `eligible_ihp_applications`: Number of approved FEMA IHP applications   
- `ihp_eligibility_rate`: Percentage of FEMA IHP applications approved (eligible applications divided by valid applications)  
- `ihp_average_award`: Average amount awarded per eligible FEMA IHP application (USD) (total IHP divided by eligible applications)  
- `ihp_total`: Total FEMA IHP funding allocated (USD). Note that FEMA pushes updates to its individual incident websites on a rolling basis; there may be discrepancies between this dataset and the “funding obligations” section of FEMA incident websites between dataset updates, especially for recent incidents.  
- `pa_total`: Total FEMA Public Assistance funding allocated (USD)  
- `pa_projects_count`: Number of FEMA Public Assistance projects  
- `cdbg_dr_allocation`: Sum of all HUD Community Development Block Grant-Disaster Recovery allocation amounts (USD) for the incident

#### Federal Register Notices (FRN)

Congress appropriates funding to HUD for individual incidents on an emergency basis; HUD publishes its allocations to jurisdictions in the Federal Register. Based on the number of Congressional appropriations for an individual disaster, there are up to four Federal Register Notices (FRN1-FRN4) for an incident:

- `frn{n}_date`: Publication date of the nth Federal Register Notice  
- `frn{n}_url`: URL to access the Federal Register Notice  
- `days_to_frn1`: Days between presidential disaster declaration and first FRN

For each FRN, multiple grantees may be listed for an individual incident (up to 9 for FRN1, up to 4 for FRN2-4). For example, for 2011 Alabama Severe Storms, Tornadoes, Straight-line Winds, and Flooding (1971), there are four grantees in FRN1: State of Alabama, City of Tuscaloosa, Jefferson County, and City of Birmingham. Each grantee received CDBG-DR funding to recover from the incident.

- `frn{n}_grantee{m}_name`: Name of the mth grantee for FRN n  
- `frn{n}_grantee{m}_url`: Associated URL for the grantee  
- `frn{n}_grantee{m}_amount`: Amount allocated to the grantee (USD). Note that HUD often allocates funding to an individual grantee for multiple incidents. The original amount in the FRN is divided equally across the incidents in the dataset. Refer to the FRN to identify the original allocation amount. 

## Data Formats

- Dates: ISO 8601 format (YYYY-MM-DD)  
- Missing Values: Represented as NULL  
- Monetary Values: All amounts in USD, stored as numbers without currency symbols or thousand separators  
- Percentages: Stored as decimal numbers without percentage sign (e.g., 47.8 for 47.8%)

## Usage Notes

1. Some disasters may not have all FRNs or grantees  
2. Some disasters may not have IHP and or PA  
3. Monetary values should be treated as historical amounts from time of allocation  
4. URLs should be verified before use as they may change over time  
5. Carnegie’s Sustainability, Climate, and Geopolitics program maintains backup copies of OpenFEMA and relevant Federal Register Notices. 

## Data Update Frequency

The current version shows data up to January 2025\.

## Contact Information

Please contact Sarah Labowitz at [sarah.labowitz@ceip.org](mailto:sarah.labowitz@ceip.org) with any inquiries.  
